source

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 19, 2026 License: EUPL-1.2 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GitSource

type GitSource struct {
	URL     string
	Version string
}

GitSource represents a remote Git repository.

func (*GitSource) Fetch

func (s *GitSource) Fetch(ctx context.Context, dest string) error

Fetch clones the Git repository to the destination directory.

type LocalSource

type LocalSource struct {
	Path string
}

LocalSource represents a local directory.

func (*LocalSource) Fetch

func (s *LocalSource) Fetch(_ context.Context, dest string) error

Fetch copies the local directory to the destination.

type Source

type Source interface {
	Fetch(ctx context.Context, dest string) error
}

Source represents a template source that can be fetched.

func Parse

func Parse(input string) (Source, error)

Parse analyzes the input string and returns the appropriate Source.

Jump to