package
Version:
v0.8.0
Opens a new window with list of versions in this module.
Published: Apr 19, 2026
License: EUPL-1.2
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GitSource represents a remote Git repository.
Fetch clones the Git repository to the destination directory.
type LocalSource struct {
Path string
}
LocalSource represents a local directory.
Fetch copies the local directory to the destination.
Source represents a template source that can be fetched.
Parse analyzes the input string and returns the appropriate Source.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.